@@ -3,10 +3,11 @@ use warnings;
 
 package Number::Format::SouthAsian;
 BEGIN {
-  $Number::Format::SouthAsian::VERSION = '0.05';
+  $Number::Format::SouthAsian::VERSION = '0.06';
 }
 
 use Carp;
+use English qw(-no_match_vars);
 use Scalar::Util qw(looks_like_number);
 
 =head1 NAME
@@ -15,7 +16,7 @@ Number::Format::SouthAsian - format numbers in the South Asian style
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -133,6 +134,11 @@ sub _format_number_wordy {
     if ($number =~ m/^ ( \d+ (?: [.]\d+)?) e[+] (\d+) $/msx) {
         my ($mantissa, $exponent) = ($1, $2);
 
+        ## in MSWin32 the exponent has an extra 0 on the front...
+        if ($OSNAME eq 'MSWin32') {
+            $exponent =~ s/^0+//;
+        }
+
         if ($mantissa <= 1) {
             $zeroes = $exponent;
         }
